@@ -51,7 +51,7 @@
 #include "configdialog.h"
 #include "qvaluebutton.h"
 
-#define APP_VER "0.0.25"
+#define APP_VER "0.0.26"
 #define APP_FIRSTLAUNCH false
 
 #ifdef Q_WS_MAEMO_5
@@ -84,12 +84,14 @@ public slots:
     void positionUpdated(QGeoPositionInfo geoPositionInfo);
     Q_SCRIPTABLE int top_application();
     void orientationChanged();
+    void updateProgress();
 
 private slots:
     void searchButtonClicked(bool checked = false);
     void aboutButtonClicked();
     void donateButtonClicked();
     void alarmButtonClicked();
+    void alarmDefaultButtonClicked();
     void settingsButtonClicked();
     void earlierButtonClicked();
     void laterButtonClicked();
@@ -118,8 +120,14 @@ private:
     QGeoPositionInfo myPositionInfo;
     QPointer<QGeoPositionInfoSource> locationDataSource;
     QSettings          *settings;
+    QDial *progressbar;
+    QDial *progressbarResult;
+    QScrollArea *scrollAreaResult;
+    QTimer *timer;
+    int progress;
     bool locationDataSourceIsUpdating;
 
+
     parserAbstract *backendParser;
 
     bool detailsLoading;
