@@ -25,8 +25,8 @@ parserMobileBahnDe::parserMobileBahnDe(QObject *parent)
      Q_UNUSED(parent);
      http = new QHttp(this);
 
-     connect(http, SIGNAL(requestFinished(int,bool)),
-             this, SLOT(httpRequestFinished(int,bool)));
+     connect(http, SIGNAL(requestFinished(int,bool)), this, SLOT(httpRequestFinished(int,bool)));
+     connect(http, SIGNAL(dataReadProgress(int,int)), this, SLOT(httpDataReadProgress(int,int)));
 }
 
 bool parserMobileBahnDe::supportsGps()
@@ -203,7 +203,7 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
     QString xhtml = filebuffer->buffer();
 
     //We use Regex to get each element details page
-    QRegExp regexp = QRegExp("<div class=\"haupt rline\">(.*)</div>");
+    QRegExp regexp = QRegExp("<div class=\"rline haupt\"  >(.*)</div>");
     regexp.setMinimal(true);
 
     int idx = 0;
@@ -678,6 +678,8 @@ QStringList parserMobileBahnDe::getStationsByName(QString stationName)
     postData.append(stationName);
     postData.append("\" t=\"ST\" /></MLcReq></ReqC>");
 
+    qDebug() << "parserMobileBahnDe::getStationsByName";
+
     QUrl url("http://mobile.bahn.de/bin/mobil/query.exe/en");
 
     http->setHost(url.host(), QHttp::ConnectionModeHttp, url.port() == -1 ? 0 : url.port());
