@@ -25,8 +25,8 @@ parserMvvDe::parserMvvDe(QObject *parent)
      Q_UNUSED(parent);
      http = new QHttp(this);
 
-     connect(http, SIGNAL(requestFinished(int,bool)),
-             this, SLOT(httpRequestFinished(int,bool)));
+     connect(http, SIGNAL(requestFinished(int,bool)), this, SLOT(httpRequestFinished(int,bool)));
+     connect(http, SIGNAL(dataReadProgress(int,int)), this, SLOT(httpDataReadProgress(int,int)));
 }
 
 bool parserMvvDe::supportsGps()
@@ -52,6 +52,8 @@ QStringList parserMvvDe::getStationsByName(QString stationName)
     QByteArray postData = "sessionID=0&requestID=0&language=en&command=&ptOptionsActive=0&place_origin=&placeState_origin=empty&type_origin=stop&nameState_origin=empty&place_destination=&placeState_destination=empty&type_destination=stop&name_destination=&nameState_destination=empty&place_via=&placeState_via=empty&type_via=stop&name_via=&name_origin=";
     postData.append(stationName);
 
+    qDebug() << "parserMVVDe::getStationsByName";
+
     QUrl url("http://efa.mvv-muenchen.de/bcl/XSLT_TRIP_REQUEST2?language=en");
 
     http->setHost(url.host(), QHttp::ConnectionModeHttp, url.port() == -1 ? 0 : url.port());
@@ -92,7 +94,7 @@ QStringList parserMvvDe::getStationsByName(QString stationName)
     QStringList result;
     if (!query.evaluateTo(&result))
     {
-        qDebug() << "parserMobileBahnDe::getStationsByName - Query 1 Failed";
+        qDebug() << "parserMVVDe::getStationsByName - Query 1 Failed";
     }
 
     //One Entry only
