@@ -57,6 +57,7 @@ public slots:
     void gpsButtonClicked(bool checked);
     void stationSelected(QString value);
     void orientationChanged();
+    void updateProgress();
 
 private:
     QComboBox   *searchboxCombo;
@@ -64,12 +65,16 @@ private:
     QPushButton *gpsButton;
     QPushButton *searchButton;
     QValueButton *mainSender;
+    QDial *progressbar;
+    QTimer *timer;
+    int progress;
     #ifdef Q_WS_MAEMO_5
     QGeoPositionInfo *myPositionInfo;
     #endif
     QSettings          *settings;
 
     void showSelector(QStringList items);
+    void closeEvent(QCloseEvent *event);
 
     parserAbstract *backendParser;
 };
